@@ -5,11 +5,11 @@
 # Release 2020-10-12
 # By Daniel Tufvesson
 #
-MAKERESOLVEDEB_VERSION=1.1
+MAKERESOLVEDEB_VERSION=1.2
 
 check_command() {
     echo -n "Checking for ${1}..."
-    if [[ ! -x "$(command -v $1)" ]]; then
+    if [ ! -x "$(command -v $1)" ]; then
 	echo "Missing! Sorry, seed '$1' to continue."
 	exit 1
     fi
@@ -17,7 +17,7 @@ check_command() {
 }
 
 copy_object() {
-    if [[ -e "$1" ]] ; then
+    if [ -e "$1" ] ; then
 	#echo "[COPY] $1 [TO] $2"
 	if ! cp -rp "$1" "$2";
 	then
@@ -35,7 +35,7 @@ link_object() {
 }
 
 create_directory() {
-    if [[ -e "$1" ]] ; then
+    if [ -e "$1" ] ; then
 	echo "[ERROR: DIRECTORY EXISTS] $1"
 	ERRORS=$((ERRORS+1))
     else
@@ -45,7 +45,7 @@ create_directory() {
 }
 
 createf_directory() {
-    if [[ -e "${1}" ]] ; then
+    if [ -e "${1}" ] ; then
 	chmod a+w -R ${1}
 	rm -rf ${1}
     fi
@@ -63,7 +63,7 @@ remove_directory() {
 }
 
 extract_tgz() {
-    if [[ -f "$1" ]] ; then
+    if [ -f "$1" ] ; then
 	#echo "[EXTRACT] $1 [TO] $2/$3"
 	tar -zxf "$1" -C "$2" "$3"
     else
@@ -73,7 +73,7 @@ extract_tgz() {
 }
 
 make_executable() {
-    if [[ -e "$1" ]] ; then
+    if [ -e "$1" ] ; then
 	#echo "[MAKE EXECUTABLE] $1"
 	chmod a+x "$1"
     else
